@@ -30,6 +30,8 @@ test_that("cpts to grain", {
   g <- compile_grain(params(a))
   # Check compiled
   expect_true(g$isCompiled)
-  p <- gRain::predict.grain(g, 'Class', newdata = voting[, -17] )
-  expect_true(all(p$pred[[1]] %in% levels(voting$Class)))
+  # gRain cannot handle a row that has all missing features. remove 249.
+  p <- gRain::predict.grain(g, response = 'Class',  
+                            newdata = voting[-249, -17], type = "class")
+  expect_true(all(p$pred[[1]] %in% levels(voting$Class[-249])))
 })
\ No newline at end of file
